uncertain_panda
===============

.. image:: https://badge.fury.io/py/uncertain_panda.svg
           :target: https://badge.fury.io/py/uncertain_panda
.. image:: https://coveralls.io/repos/github/nils-braun/uncertain_panda/badge.svg?branch=master
           :target: https://coveralls.io/github/nils-braun/uncertain_panda?branch=master
.. image:: https://travis-ci.org/nils-braun/uncertain_panda.svg?branch=master
           :target: https://travis-ci.org/nils-braun/uncertain_panda


``uncertain_panda`` helps you with constructing uncertainties of quantities calculated on your ``pandas`` data frames,
by applying the method of bootstrapping.

More information will come soon!